@@ -27,18 +27,16 @@ sub defaults {
             menu_memory          => 1,
             metadata             => 0,
             operators            => [ "REGEXP", "REGEXP_i", " = ", " != ", " < ", " > ", "IS NULL", "IS NOT NULL" ],
-            plugins              => [ 'SQLite', 'mysql', 'Pg', 'Firebird' ],
+            plugins              => [ 'SQLite' ],
             qualified_table_name => 0,
             quote_identifiers    => 1,
             db2_encoding         => 'utf8',
         },
         alias => {
-            select        => 0,
-            aggregate     => 0,
-            derived_table => 0,
-            join          => 0,
-            union         => 0,
-            use_defaults  => 1,
+            select_func_sq => 0,
+            derived_table  => 0,
+            join           => 0,
+            union          => 0,
         },
         enable => {
             create_table => 0,
