@@ -120,13 +120,7 @@ sub union_tables {
         }
     }
     my $qt_table = $ax->get_stmt( $union, 'Union', 'prepare' );
-    my $dummy_identifier;
-    if ( $sf->{o}{alias}{use_defaults} ) {
-        $dummy_identifier = 'UNION_ALL_' . join( '_', @{$union->{used_tables}} );
-    }
-    else {
-        $dummy_identifier = 'UNION_ALL';
-    }
+    my $dummy_identifier = 'UNION_ALL_' . join( '_', @{$union->{used_tables}} ); ##
     my $alias = $ax->alias( $union, 'union', $dummy_identifier, $dummy_identifier );
     if ( length $alias ) {
         $qt_table .= " AS " . $ax->prepare_identifier( $alias );
